@@ -10,7 +10,7 @@ tar zxf /usr/share/doc/allegro4-doc/examples/*tar.gz
 #gunzip -v *.gz
 echo "Compiling examples..."
 for src in *.c; do
-  gcc -g -O2 -o ${src%.c} $src `allegro-config --libs`
+  gcc -g -O2 -o ${src%.c} $src `allegro-config --libs` -lm
 #  strip ${src%.c}
 done
 echo "Compiled example programs are now in ~/allegro4-examples"
